@@ -1,14 +1,12 @@
 testname=$1
 echo "
   EXECUTE SCRIPT (
-       SET ID = 1,
        FILENAME = '${testname}/ddl_updates.sql',
        EVENT NODE = 1
     );
 
   try {
        execute script (
-            set id=1,
             filename='${testname}/bad_ddl.sql',
             event node=1
        );
