@@ -5,6 +5,6 @@ for tbl in master sub1 sub2 sub3 regions products sales_data us_east us_west can
 done
 
 
-for tbl in master products sales_data; do
+for tbl in master sales_data; do
   echo "grant select on table public.${tbl}_id_seq to ${weakuser};"
 done
\ No newline at end of file
