@@ -51,7 +51,7 @@ $slonik .= "  try {\n";
 $slonik .= "    SET DROP TABLE (id = $TABLE_ID, origin = $SET_ORIGIN);\n";
 $slonik .= "  } on error {\n";
 $slonik .= "    echo 'Could not drop table $TABLE_ID for $CLUSTER_NAME!';\n";
-$slonik .= "    exit -1;\n";
+$slonik .= "    exit 1;\n";
 $slonik .= "  }\n";
 
 run_slonik_script($slonik, 'DROP TABLE');
